==> wsclient-8.0.4-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wspackageprocess/WsPackageProcessPingResponseWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wspackageprocess;



/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2019 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: WsPackageProcessPingResponseWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wspackageprocess.v1_04.WsPackageProcessPingResponse
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wspackageprocess
 * TimeStamp: 2020-09-23T03:53:35.737Z
 */
public class WsPackageProcessPingResponseWrapper
{

	public WsPackageProcessPingResponseWrapper() {}

	public org.hpccsystems.ws.client.gen.axis2.wspackageprocess.v1_04.WsPackageProcessPingResponse getRaw()
	{
		org.hpccsystems.ws.client.gen.axis2.wspackageprocess.v1_04.WsPackageProcessPingResponse raw = new org.hpccsystems.ws.client.gen.axis2.wspackageprocess.v1_04.WsPackageProcessPingResponse();
		return raw;
	}


}

==> wsclient-9.4.24-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wspackageprocess/WsPackageProcessPingResponseWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wspackageprocess;

/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2021 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: WsPackageProcessPingResponseWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wspackageprocess.latest.WsPackageProcessPingResponse
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wspackageprocess
 */
public class WsPackageProcessPingResponseWrapper
{

    public WsPackageProcessPingResponseWrapper() {}

    public org.hpccsystems.ws.client.gen.axis2.wspackageprocess.latest.WsPackageProcessPingResponse getRaw()
    {
        org.hpccsystems.ws.client.gen.axis2.wspackageprocess.latest.WsPackageProcessPingResponse raw = new org.hpccsystems.ws.client.gen.axis2.wspackageprocess.latest.WsPackageProcessPingResponse();
        return raw;
    }


}
